# mock resource classes from peeringdb-py client


class Organization(object):
    pass


class Facility(object):
    pass


class Network(object):
    pass


class InternetExchange(object):
    pass


class InternetExchangeFacility(object):
    pass


class InternetExchangeLan(object):
    pass


class InternetExchangeLanPrefix(object):
    pass


class NetworkFacility(object):
    pass


class NetworkIXLan(object):
    pass


class NetworkContact(object):
    pass
